table {
    color: #666 !important;
}
table.wildewidgets-table {
    margin-top: 5px;
}
td, th, tbody {
    border-bottom-color: #eee !important;
}
table.dataTable.no-footer {
    border-bottom: 1px solid #eee;
}
tbody {
    border-top: 1px solid #eee !important;
}

.dataTables_info {
    padding-left: 15px !important;
}

button.toggle-vis.btn-outline-secondary:not(.active) {
    color: #fff;
    background-color: #6c757d;
    border-color: #6c757d;
}
td {
    vertical-align: middle !important;
}

table.dataTable.table-sm tbody th, 
table.dataTable.table-sm tbody td {
    padding: .25rem 0.25rem;
}
